tl_get_messages: Get SMS messages.

Description Usage Arguments

View source: R/telnyx.R

Description

Get SMS messages from the MDR reports endpoint. This reporting works as an asynchronous call to the report api and returns a CSV parsed into a data table using fread

See here for more details.

Usage

1
2
3
4
5
6
7
8
9
tl_get_messages(
  start_time,
  end_time = NULL,
  profile_ids = NULL,
  verbose = FALSE,
  v1_token,
  v1_user,
  params = NULL
)

Arguments

start_time

start time of report. Required. Must include the timezone.

end_time

optional time for end of report. Must include the timezone.

profile_ids

an optional vector of Messaging Profile ids to filter down to.

verbose

defaults to FALSE.

v1_token

Telnyx API v1 Token

v1_user

Telnyx API v1 user, either an email or the preferred masked API user id.

params

optional further arguments to pass into API query. Should be a named list.


happycabbage/twilior documentation built on July 5, 2021, 4:21 a.m.