tl_order_numbers: Purchase numbers and optionally assign to Messaging Profile.

Description Usage Arguments

View source: R/telnyx.R

Description

Purchase Telnyx numbers and optionally assign them to a Messaging Profile. This leverages a combination of the Number Search API and Number Order API to find numbers based on a series of search parameters.

Currently only configured to purchase US phone numbers.

See here for more details.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
tl_order_numbers(
  key,
  n,
  search_only = FALSE,
  incl_best_effort = FALSE,
  type = "long-code",
  area_code = NULL,
  city = NULL,
  state = NULL,
  profile_id = NULL,
  params = NULL,
  ...
)

Arguments

key

Required. Telnyx API key

n

Required. Integer number of phone numbers to purchase. Maximum is 100 If less than 100 are available for the given filter parameters it will purchase all available numbers.

search_only

Boolean. If TRUE will return only the results of the number search and not purchase the numbers. Defaults to FALSE.

incl_best_effort

Boolean. If TRUE will include 'best effort' results, i.e. results that are close to the filtered parameters (e.g. geographically) but are not exactly within the filter. Defaults to FALSE in order to make this decision explicit by the user.

type

the type of phone number to purchase. Options are 'toll-free' and 'long-code'. Defaults to 'long-code'.

area_code

Optional. Specify the 3 digit area code the phone number should be associated with as a character string.

city

Optional. City that the phone number should be in. It is recommended to use this in conjunction with the state parameter.

state

Optional. Two character state abbreviation that the phone number should be in.

profile_id

Optional. The messaging profile to assign the numbers to.

params

Optional further arguments to pass into API body. Should be a named list.

...

Unused at this time.


happycabbage/twilior documentation built on July 5, 2021, 4:21 a.m.