tl_send_msg_profile: Send SMS via a Number Pool attached to Telnyx Messaging...

Description Usage Arguments

View source: R/telnyx.R

Description

Send an SMS through the Number Pool Feature of Telnyx. Specifically to the "https://api.telnyx.com/v2/messages/number_pool" endpoint. This is the recommended way of sending texts because it takes advantage of all the Messaging Profile features Which include things like matching locale and sticky sender. You also don't need need to remember which phone number to use as the sending number.

See here for more details.

Usage

1
tl_send_msg_profile(to, message, profile_id, key, params = NULL)

Arguments

to

the number to send the message to

message

the message to send

profile_id

messaging profile id

key

Telnyx API key

params

optional further params to pass into the API call. Should be a named list.


happycabbage/twilior documentation built on July 5, 2021, 4:21 a.m.