tl_set_call_fwd: Setup call forwarding for a given Messaging Profile

Description Usage Arguments

View source: R/telnyx.R

Description

Sets call forwarding up for a given Messaging Profile.

See here for more details.

Usage

1
tl_set_call_fwd(key, fwd_number, profile_id = NULL, phone_ids = NULL, ...)

Arguments

key

Required. Telnyx API key.

fwd_number

Required. Phone number to forward to. Should be a string in the format +14156660420.

profile_id

Messaging Profile id to update all numbers. Required if phone_ids are not set.

phone_ids

Vector of phone ids to update. Note these are not the phone numbers, but the Telnyx assigned ID. Required if profile_id is not set.

...

Unused at this time.


happycabbage/twilior documentation built on July 5, 2021, 4:21 a.m.