tw_notify_twilio: Send a message through the Twilio Notify Service.

Description Usage Arguments

View source: R/twilio.R

Description

Send a message with the Twilio Notify API. Specifically to the "https://notify.twilio.com/v1/Services/YOUR_NOTIFY_TOKEN/Notifications" endpoin.

See here for more details. Unless you are a user of the Notify API and are trying to send notifcations across device types I suggest using tw_send_messaging_service With your favorite apply, purrr:map, or for(m in messages) equivalent.

Usage

1
2
3
4
5
6
7
8
tw_notify_twilio(
  message,
  tag,
  service_sid = Sys.getenv("TWILIO_NOTIFY_SID"),
  sid = Sys.getenv("TWILIO_SID"),
  token = Sys.getenv("TWILIO_TOKEN"),
  params = NULL
)

Arguments

message

character string of the text

tag

character string of the Twilio Notify tag you are messaging. See here

service_sid

optional explicit decleration of TWILIO_NOTIFY_SID defaults to Sys.getenv('TWILIO_NOTIFY_SERVICE'. See here..

sid

Twilio account sid. Defaults to Sys.getenv('TWILIO_SID')

token

Twilio account token. Defaults to Sys.getenv('TWILIO_TOKEN')

params

further optional vakues to send into the API call (e.g. identity). Should be a named ;ist. See here


happycabbage/twilior documentation built on July 5, 2021, 4:21 a.m.