Create a Telnyx Messaging Profile via the Messgaging Profiles endpoint.
See here for more details.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 | tl_create_msg_profile(
key,
name = NULL,
geomatch = TRUE,
skip_unhealthy = FALSE,
sticky_sender = TRUE,
long_code_weight = 1,
toll_free_weight = 1,
whitelisted_destinations = "US",
webhook_url = "",
webhook_failover_url = "",
params = NULL,
...
)
tl_update_msg_profile(key, profile_id, params)
|
key |
Required. Telnyx API key |
name |
Optional. A user friendly name for the messaging profile. |
geomatch |
Should numbers match area codes? Defaults to TRUE. |
skip_unhealthy |
Should numbers that are blocked not be used? Defaults to FALSE. |
sticky_sender |
Should contacts receive messages from the same number? Defaults to TRUE. |
long_code_weight |
Probability of using Long Code (as a share of the sum of the weights). Defaults to 1. |
toll_free_weight |
Probability of using Toll Free (as a share of the sum of the weights). Defaults to 1. |
whitelisted_destinations |
Vector of country codes numbers can send to. Defaults to 'US'. Should be ISO 3166-1 alpha-2 country codes. |
webhook_url |
Optional. URL for webhook response. |
webhook_failover_url |
Optional. Backup URL for webhook response. |
params |
Optional further arguments to pass into API body. Should be a named list.
Required if using |
... |
Unused at this time. |
profile_id |
The messaging profile to update. Required for |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.