Purchase Telnyx numbers and optionally assign them to a Messaging Profile. This leverages a combination of the Number Search API and Number Order API to find numbers based on a series of search parameters.
Currently only configured to purchase US phone numbers.
See here for more details.
1 2 3 4 5 6 7 8 9 10 11 12 13 |
key |
Required. Telnyx API key |
n |
Required. Integer number of phone numbers to purchase. Maximum is 100 If less than 100 are available for the given filter parameters it will purchase all available numbers. |
search_only |
Boolean. If |
incl_best_effort |
Boolean. If |
type |
the type of phone number to purchase. Options are 'toll-free' and 'long-code'. Defaults to 'long-code'. |
area_code |
Optional. Specify the 3 digit area code the phone number should be associated with as a character string. |
city |
Optional. City that the phone number should be in. It is recommended to use this in conjunction with the |
state |
Optional. Two character state abbreviation that the phone number should be in. |
profile_id |
Optional. The messaging profile to assign the numbers to. |
params |
Optional further arguments to pass into API body. Should be a named list. |
... |
Unused at this time. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.