Sets call forwarding up for a given Messaging Profile.
See here for more details.
1 | tl_set_call_fwd(key, fwd_number, profile_id = NULL, phone_ids = NULL, ...)
|
key |
Required. Telnyx API key. |
fwd_number |
Required. Phone number to forward to. Should be a string in the format +14156660420. |
profile_id |
Messaging Profile id to update all numbers. Required if |
phone_ids |
Vector of phone ids to update. Note these are not the phone numbers, but the Telnyx assigned ID. Required if |
... |
Unused at this time. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.