Setup a messaging profile, purchase a set of numbers, and apply call forwarding.
This is a convenience wrapper around tl_create_msg_profile, tl_order_numbers, and tl_set_call_fwd
If you want more specific settings use those functions individually or pass in function parameters.
See here for more details.
1 2 3 4 5 6 7 8 9 10 | tl_setup_msg_profile(
api_key,
profile_name,
n_phone_numbers,
profile_state,
profile_city = NULL,
call_fwd_number = NULL,
verbose = FALSE,
...
)
|
api_key |
Required. Telnyx API key. |
profile_name |
Required. Messaging Profile name. |
n_phone_numbers |
Required. Number of phone numbers to allocate to the Messaging Service. |
profile_state |
Required. Abbreviated state name to look up phone numbers. e.g. CA, OR, CO, etc. |
profile_city |
Optional. City name to narrow down the search to provision phone numbers. |
call_fwd_number |
Optional. Phone number to forward to. Should be a string in the format +14156660420. |
verbose |
Defaults to |
... |
Optional further parameters to pass into other functions. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.