Send a message with the Twilio Notify API. Specifically to the "https://notify.twilio.com/v1/Services/YOUR_NOTIFY_TOKEN/Notifications" endpoin.
See here for more details.
Unless you are a user of the Notify API and are trying to send notifcations across device types I suggest using tw_send_messaging_service
With your favorite apply, purrr:map, or for(m in messages) equivalent.
1 2 3 4 5 6 7 8 | tw_notify_twilio(
message,
tag,
service_sid = Sys.getenv("TWILIO_NOTIFY_SID"),
sid = Sys.getenv("TWILIO_SID"),
token = Sys.getenv("TWILIO_TOKEN"),
params = NULL
)
|
message |
character string of the text |
tag |
character string of the Twilio Notify tag you are messaging. See here |
service_sid |
optional explicit decleration of |
sid |
Twilio account sid. Defaults to |
token |
Twilio account token. Defaults to |
params |
further optional vakues to send into the API call (e.g. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.