Send a text with the Twilio API. Specifically to the "https://api.twilio.com/2010-04-01/Accounts/YOUR_SID/Messages.json" endpoint
Works similar twilio::tw_send_message() only we are explicit that this is a text message, and allow the sid and token to be passed in as parameters
Note that using tw_send_messaging_service is the preferred way of sending multiple SMS as it is more feature rich.
See here for more details.
1 2 3 4 5 6 7 8 | tw_send_text(
to,
from,
message,
sid = Sys.getenv("TWILIO_SID"),
token = Sys.getenv("TWILIO_TOKEN"),
params = NULL
)
|
to |
number to send the text to |
from |
number to send the text from |
message |
character string of the text |
sid |
Twilio account sid. Defaults to |
token |
Twilio account token. Defaults to |
params |
optional further params to pass into the API call. Should be a named list. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.